@@ -5,8 +5,11 @@ use {
     jsonrpc_ipc_server::{RequestContext, ServerBuilder},
     jsonrpc_server_utils::tokio,
     log::*,
-    solana_core::validator::{ValidatorExit, ValidatorStartProgress},
-    solana_sdk::signature::{read_keypair_file, Keypair, Signer},
+    solana_core::validator::ValidatorStartProgress,
+    solana_sdk::{
+        exit::Exit,
+        signature::{read_keypair_file, Keypair, Signer},
+    },
     std::{
         net::SocketAddr,
         path::Path,
@@ -21,7 +24,7 @@ pub struct AdminRpcRequestMetadata {
     pub rpc_addr: Option<SocketAddr>,
     pub start_time: SystemTime,
     pub start_progress: Arc<RwLock<ValidatorStartProgress>>,
-    pub validator_exit: Arc<RwLock<ValidatorExit>>,
+    pub validator_exit: Arc<RwLock<Exit>>,
     pub authorized_voter_keypairs: Arc<RwLock<Vec<Arc<Keypair>>>>,
 }
 impl Metadata for AdminRpcRequestMetadata {}
@@ -67,7 +70,7 @@ impl AdminRpc for AdminRpcImpl {
             warn!("validator exit requested");
             meta.validator_exit.write().unwrap().exit();
 
-            // TODO: Debug why ValidatorExit doesn't always cause the validator to fully exit
+            // TODO: Debug why Exit doesn't always cause the validator to fully exit
             // (rocksdb background processing or some other stuck thread perhaps?).
             //
             // If the process is still alive after five seconds, exit harder
@@ -122,13 +125,7 @@ impl AdminRpc for AdminRpcImpl {
 
     fn remove_all_authorized_voters(&self, meta: Self::Metadata) -> Result<()> {
         debug!("remove_all_authorized_voters received");
-        let mut a = meta.authorized_voter_keypairs.write().unwrap();
-
-        error!("authorized_voter_keypairs pre len: {}", a.len());
-        a.clear();
-        error!("authorized_voter_keypairs post len: {}", a.len());
-
-        //meta.authorized_voter_keypairs.write().unwrap().clear();
+        meta.authorized_voter_keypairs.write().unwrap().clear();
         Ok(())
     }
 }
@@ -137,9 +134,10 @@ impl AdminRpc for AdminRpcImpl {
 pub fn run(ledger_path: &Path, metadata: AdminRpcRequestMetadata) {
     let admin_rpc_path = ledger_path.join("admin.rpc");
 
-    let event_loop = tokio::runtime::Builder::new_multi_thread()
-        .thread_name("sol-adminrpc-el")
+    let event_loop = tokio::runtime::Builder::new()
+        .threaded_scheduler()
         .enable_all()
+        .thread_name("sol-adminrpc-el")
         .build()
         .unwrap();
 
